@@ -39,9 +39,13 @@ def override_dpy():
 
     #region message override
     async def send(self: discord.TextChannel, content=None, **kwargs) -> Message:
+        channel_id = self.id if not isinstance(self, commands.Context) else self.channel.id
 
-
-        channel_id = self.id if type(self) is not commands.Context else self.channel.id
+        if isinstance(self, discord.Member):
+            if self.dm_channel == None:
+                dm_chnl = await self.create_dm()
+                channel_id = dm_chnl.id
+        
         route = BetterRoute("POST", f"/channels/{channel_id}/messages")
         
         r = None
@@ -56,7 +60,7 @@ def override_dpy():
             payload = jsonifyMessage(content=content, **kwargs)
             r = await send_files(route, files=files, payload=payload, http=self._state.http)
         
-        msg = Message(state=self._state, channel=self if type(self) is not commands.Context else self.channel, data=r)
+        msg = Message(state=self._state, channel=self if not isinstance(self, commands.Context) else self.channel, data=r)
         if kwargs.get("delete_after") is not None:
             await msg.delete(delay=kwargs.get("delete_after"))
     
